@@ -9,7 +9,8 @@ use spa::{calc_sunrise_and_set, SunriseAndSet};
 fn main() {
 
     // test-vector from http://lexikon.astronomie.info/zeitgleichung/neu.html
-    let dt = Utc.ymd(2005, 9, 30).and_hms(12, 0, 0);
+    let dt = Utc.with_ymd_and_hms(2005, 9, 30, 12, 0, 0)
+        .single().unwrap();
 
     // geo-pos near Frankfurt/Germany
     let lat = 50.0;
